//  ColorHCFR
//  HCFRDataStoreIOCategory.h
// -----------------------------------------------------------------------------
//  Created by Jérôme Duquennoy on 26/12/07.
//
//  $Rev: 51 $
//  $Date: 2008-05-22 14:48:37 +0200 (Thu, 22 May 2008) $
//  $Author: jerome $
// -----------------------------------------------------------------------------
// This program is free software; you can redistribute it and/or modify it under the terms of the GNU
// General Public License as published by the Free Software Foundation; either version 2 of the License,
// or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even
// the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
// Public License for more details.
//
// You should have received a copy of the GNU General Public License along with this program; if not,
// write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// -----------------------------------------------------------------------------


#import <Cocoa/Cocoa.h>
#import <HCFRPlugins/HCFRDataSerie.h>

#define kHCFRDataStoreSaveFailureException @"DataStoreSaveFailure"

/*!
    @class
    @abstract    (brief description)
    @discussion  (comprehensive description)
*/
@interface HCFRDataSerie  (IO) <NSCoding>
/*!
 @function 
 @abstract   Charge les données à partir d'un fichier CSV
 @discussion Cette fonction permet de charger les données à fournir lors des mesures
 d'un fichier dont l'URL est passée en argument.
 Le fichier est un fichier CVS, dont chaque ligne est au format suivant :
 type, reference, x, y, z
 type est un entier, toutes les autres données dont des double.
 Attention, ce format perd des informations : les matrices de transformation présentes dans les
 instances de Color, sont perdues, seul les valeurs XYZ sont sauvegardées. La matrice de transformation
 est la matrice unité après chargement.
 @param      filePath L'URL du fichier à charger
 */
-(void) loadDataFromCSVFile:(NSString*)filePath;  

/*!
   @function 
   @abstract   Enregistre les données dans un fichier CSV
   @discussion Cette fonction permet de sauvegarder les données stockées dans le dataStore
   dans un fichier dont l'URL est passée en argument.
   Le fichier est un fichier CVS, dont chaque ligne est au format suivant :
   type, reference, x, y, z
   type est un entier, toutes les autres données dont des double.
   Attention, ce format perd des informations : les matrices de transformation présentes dans les
   instances de Color, sont perdues, seul les valeurs XYZ sont sauvegardées. La matrice de transformation
   est la matrice unité après chargement.
   @param      filePath L'URL du fichier à charger
*/
-(void) saveDataToCSVFile:(NSString*)filePath;
@end
